<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="ca" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="24"/>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Automatically save documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Restore window geometry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Restore live preview state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Open external links in ReText window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Open unknown files in plain text mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Highlight current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Show line numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Tab key inserts spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Tabulation width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Display right margin at column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Icon theme name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="34"/>
        <source>Enter locale name (example: en_US)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialogs.py" line="39"/>
        <source>Set as default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="92"/>
        <source>File toolbar</source>
        <translation>Barra d&apos;eines Fitxer</translation>
    </message>
    <message>
        <location filename="window.py" line="94"/>
        <source>Edit toolbar</source>
        <translation>Barra d&apos;eines Edita</translation>
    </message>
    <message>
        <location filename="window.py" line="96"/>
        <source>Search toolbar</source>
        <translation>Barra d&apos;eines de Cerca</translation>
    </message>
    <message>
        <location filename="window.py" line="100"/>
        <source>New</source>
        <translation>Nou</translation>
    </message>
    <message>
        <location filename="window.py" line="103"/>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <location filename="window.py" line="109"/>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
    <message>
        <location filename="window.py" line="113"/>
        <source>Save as</source>
        <translation>Anomena i desa</translation>
    </message>
    <message>
        <location filename="window.py" line="115"/>
        <source>Print</source>
        <translation>Imprimeix</translation>
    </message>
    <message>
        <location filename="window.py" line="118"/>
        <source>Print preview</source>
        <translation>Imprimeix la vista prèvia</translation>
    </message>
    <message>
        <location filename="window.py" line="120"/>
        <source>View HTML code</source>
        <translation>Veure el codi HTML</translation>
    </message>
    <message>
        <location filename="window.py" line="121"/>
        <source>Change default font</source>
        <translation>Canvia la lletra per defecte </translation>
    </message>
    <message>
        <location filename="window.py" line="122"/>
        <source>Find text</source>
        <translation>Cerca el text</translation>
    </message>
    <message>
        <location filename="window.py" line="126"/>
        <source>Preview</source>
        <translation>Vista prèvia</translation>
    </message>
    <message>
        <location filename="window.py" line="135"/>
        <source>Live preview</source>
        <translation>Vista prèvia en directe</translation>
    </message>
    <message>
        <location filename="window.py" line="137"/>
        <source>Fullscreen mode</source>
        <translation>Mode de pantalla completa</translation>
    </message>
    <message>
        <location filename="window.py" line="145"/>
        <source>Quit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <location filename="window.py" line="148"/>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <location filename="window.py" line="150"/>
        <source>Redo</source>
        <translation>Refés</translation>
    </message>
    <message>
        <location filename="window.py" line="152"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="window.py" line="154"/>
        <source>Cut</source>
        <translation>Retalla</translation>
    </message>
    <message>
        <location filename="window.py" line="156"/>
        <source>Paste</source>
        <translation>Enganxa</translation>
    </message>
    <message>
        <location filename="window.py" line="166"/>
        <source>Enable</source>
        <translation>Activa</translation>
    </message>
    <message>
        <location filename="window.py" line="167"/>
        <source>Set locale</source>
        <translation>Estableix l&apos;idioma</translation>
    </message>
    <message>
        <location filename="window.py" line="168"/>
        <source>Plain text</source>
        <translation>Text pla</translation>
    </message>
    <message>
        <location filename="window.py" line="169"/>
        <source>Use WebKit renderer</source>
        <translation>Utilitza el renderitzador WebKit</translation>
    </message>
    <message>
        <location filename="window.py" line="171"/>
        <source>Generate webpages</source>
        <translation>Genera pàgines web</translation>
    </message>
    <message>
        <location filename="window.py" line="172"/>
        <source>Show</source>
        <translation>Mostra</translation>
    </message>
    <message>
        <location filename="window.py" line="173"/>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <location filename="window.py" line="175"/>
        <source>Previous</source>
        <translation>Previ</translation>
    </message>
    <message>
        <location filename="window.py" line="177"/>
        <source>Get help online</source>
        <translation>Obtingueu ajuda en línia</translation>
    </message>
    <message>
        <location filename="window.py" line="178"/>
        <source>About %s</source>
        <comment>Example of final string: About ReText</comment>
        <translation>Sobre %s</translation>
    </message>
    <message>
        <location filename="window.py" line="182"/>
        <source>About Qt</source>
        <translation>Sobre Qt</translation>
    </message>
    <message>
        <location filename="window.py" line="202"/>
        <source>Bold</source>
        <translation>Negreta</translation>
    </message>
    <message>
        <location filename="window.py" line="204"/>
        <source>Italic</source>
        <translation>Cursiva</translation>
    </message>
    <message>
        <location filename="window.py" line="206"/>
        <source>Underline</source>
        <translation>Subratllat</translation>
    </message>
    <message>
        <location filename="window.py" line="214"/>
        <source>Tags</source>
        <translation>Etiquetes</translation>
    </message>
    <message>
        <location filename="window.py" line="218"/>
        <source>Symbols</source>
        <translation>Símbols</translation>
    </message>
    <message>
        <location filename="window.py" line="231"/>
        <source>File</source>
        <translation>Fitxer</translation>
    </message>
    <message>
        <location filename="window.py" line="232"/>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <location filename="window.py" line="233"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="window.py" line="236"/>
        <source>Open recent</source>
        <translation>Obre recents</translation>
    </message>
    <message>
        <location filename="window.py" line="239"/>
        <source>Directory</source>
        <translation>Directori</translation>
    </message>
    <message>
        <location filename="window.py" line="247"/>
        <source>Export</source>
        <translation>Exporta</translation>
    </message>
    <message>
        <location filename="window.py" line="269"/>
        <source>Spell check</source>
        <translation>Comprova l&apos;ortografia</translation>
    </message>
    <message>
        <location filename="window.py" line="280"/>
        <source>Formatting</source>
        <translation>Formata</translation>
    </message>
    <message>
        <location filename="window.py" line="317"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="window.py" line="319"/>
        <source>Case sensitively</source>
        <translation>Majúscules i minúscules</translation>
    </message>
    <message>
        <location filename="window.py" line="1135"/>
        <source>New document</source>
        <translation>Document nou</translation>
    </message>
    <message>
        <location filename="window.py" line="661"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>No s&apos;ha pogut analitzar el contingut del fitxer. Comproveu que teniu instal·lat el  &lt;a href=&quot;%s&quot;&gt;mòdul  necessari&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="window.py" line="765"/>
        <source>Please, save the file somewhere.</source>
        <translation>deseu el fitxer en algun directori</translation>
    </message>
    <message>
        <location filename="window.py" line="750"/>
        <source>Failed to copy default template, please create template.html manually.</source>
        <translation>S&apos;ha produït un error en copiar la plantilla per defecte. Cal que creeu el fitxer plantilla.html manualment.</translation>
    </message>
    <message>
        <location filename="window.py" line="754"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Pàgines web desades al directori &lt;code&gt;html&lt;/code&gt;.</translation>
    </message>
    <message>
        <location filename="window.py" line="756"/>
        <source>Show directory</source>
        <translation>Mostra el directori</translation>
    </message>
    <message>
        <location filename="window.py" line="880"/>
        <source>Select one or several files to open</source>
        <translation>Seleccioneu un o més fitxers per obrir</translation>
    </message>
    <message>
        <location filename="window.py" line="880"/>
        <source>Supported files</source>
        <translation>Fitxers suportats</translation>
    </message>
    <message>
        <location filename="window.py" line="880"/>
        <source>All files (*)</source>
        <translation>Tots els fitxers (*)</translation>
    </message>
    <message>
        <location filename="window.py" line="962"/>
        <source>Plain text (*.txt)</source>
        <translation>Text pla (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="965"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s fitxers</translation>
    </message>
    <message>
        <location filename="window.py" line="1038"/>
        <source>Save file</source>
        <translation>Desa el fitxer</translation>
    </message>
    <message>
        <location filename="window.py" line="984"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>No s&apos;ha pogut desar el fitxer perquè només és de lectura</translation>
    </message>
    <message>
        <location filename="window.py" line="1029"/>
        <source>Export document to ODT</source>
        <translation>Exporta el document a ODT</translation>
    </message>
    <message>
        <location filename="window.py" line="1029"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>Fitxers de text OpenDocument (*.odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="1038"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>Fitxers HTML (*.html *htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="1059"/>
        <source>Export document to PDF</source>
        <translation>Exporta document com a PDF</translation>
    </message>
    <message>
        <location filename="window.py" line="1059"/>
        <source>PDF files (*.pdf)</source>
        <translation>Fitxers PDF (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="1075"/>
        <source>Print document</source>
        <translation>Imprimeix document</translation>
    </message>
    <message>
        <location filename="window.py" line="1096"/>
        <source>Export document</source>
        <translation>Exporta document</translation>
    </message>
    <message>
        <location filename="window.py" line="1114"/>
        <source>Failed to execute the command:</source>
        <translation>S&apos;ha produït un error a l&apos;executar el comandament:</translation>
    </message>
    <message>
        <location filename="window.py" line="1191"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>S&apos;ha modificat el document.
Voleu desar els canvis?</translation>
    </message>
    <message>
        <location filename="window.py" line="1215"/>
        <source>HTML code</source>
        <translation>Codi HTML</translation>
    </message>
    <message>
        <location filename="window.py" line="1226"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Editor de Markdown i reStructuredText senzill alhora que potent</translation>
    </message>
    <message>
        <location filename="window.py" line="1226"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Autor: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="window.py" line="1226"/>
        <source>Website</source>
        <translation>Lloc web</translation>
    </message>
    <message>
        <location filename="window.py" line="1226"/>
        <source>Markdown syntax</source>
        <translation>Sintaxi markdown</translation>
    </message>
    <message>
        <location filename="window.py" line="1226"/>
        <source>reStructuredText syntax</source>
        <translation>Sintaxi reStructuredText</translation>
    </message>
    <message>
        <location filename="window.py" line="277"/>
        <source>Default markup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="586"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="106"/>
        <source>Set encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="937"/>
        <source>Select file encoding from the list:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
